chordtools.color_chord_note_heads_by_pitch_class_color_map
==========================================================

.. autofunction:: abjad.tools.chordtools.color_chord_note_heads_by_pitch_class_color_map.color_chord_note_heads_by_pitch_class_color_map
